import { WebSocketConnection } from './communication/WebSocketConnection';
import { Logger } from './utils/Logger';
import { WebSocketBridgeCommunication } from './communication/WebSocketBridgeCommunication';
var XComponent = /** @class */ (function () {
    function XComponent() {
        this.logger = Logger.getLogger('XComponent');
        this.initialized = false;
    }
    XComponent.prototype.connect = function (serverUrl, errorListener, heartbeatIntervalSeconds) {
        var _this = this;
        if (heartbeatIntervalSeconds === void 0) { heartbeatIntervalSeconds = 10; }
        this.ensureInitialized();
        return new Promise(function (resolve, reject) {
            var webSocket;
            if (_this.isNodeApplication()) {
                process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0';
                webSocket = new WebSocket(serverUrl);
            }
            else {
                webSocket = new WebSocket(serverUrl);
            }
            var webSocketBridgeCommunication = new WebSocketBridgeCommunication(webSocket);
            var connection = new WebSocketConnection(webSocket, webSocketBridgeCommunication);
            webSocket.onopen = (function (e) {
                connection.closedByUser = false;
                webSocketBridgeCommunication.startHeartbeat(heartbeatIntervalSeconds);
                _this.logger.info('connection started on ' + serverUrl + '.');
                resolve(connection);
            }).bind(_this);
            webSocket.onerror = (function (error) {
                if (errorListener) {
                    errorListener.onError(new Error(error.toString()));
                    reject(error);
                }
                _this.logger.error('Error on ' + serverUrl + '.', error);
            }).bind(_this);
            webSocket.onclose = (function (closeEvent) {
                _this.logger.info('connection on ' + serverUrl + ' closed.', closeEvent);
                if (!connection.closedByUser && errorListener) {
                    errorListener.onError(new Error('Unxecpected connection close on ' + serverUrl));
                    reject(closeEvent);
                }
                webSocketBridgeCommunication.dispose();
                connection.dispose();
            }).bind(_this);
        });
    };
    XComponent.prototype.ensureInitialized = function () {
        if (!this.initialized) {
            this.initialized = true;
        }
    };
    XComponent.prototype.isNodeApplication = function () {
        return typeof process === 'object' && process + '' === '[object process]' && typeof window === 'undefined';
    };
    return XComponent;
}());
export { XComponent };
//# sourceMappingURL=XComponent.js.map