import { fromEvent as observableFromEvent } from 'rxjs';
import { filter, first, map, takeWhile } from 'rxjs/operators';
import { Commands } from '../configuration/xcWebSocketBridgeConfiguration';
import { Serializer, Deserializer } from './xcomponentMessages';
import 'rxjs/add/observable/fromEvent';
import { Logger } from '../utils/Logger';
import { DefaultApiConfigurationParser } from '../configuration/apiConfigurationParser';
var WebSocketBridgeCommunication = /** @class */ (function () {
    function WebSocketBridgeCommunication(webSocket) {
        var _this = this;
        this.webSocket = webSocket;
        this.logger = Logger.getLogger('HeartbeatManager');
        this.runnning = true;
        this.deserializer = new Deserializer();
        this.serializer = new Serializer();
        var thisWebSocketBridgeCommunication = this;
        this.updates$ = observableFromEvent(this.webSocket, 'message').pipe(takeWhile(function (rawMessage) { return _this.runnning; }), map(function (rawMessage) {
            return thisWebSocketBridgeCommunication.deserializer.deserializeWithoutTopic(rawMessage.data || rawMessage);
        }));
    }
    WebSocketBridgeCommunication.prototype.startHeartbeat = function (heartbeatIntervalSeconds) {
        var _this = this;
        var thisWebSocketBridgeCommunication = this;
        var command = Commands[Commands.hb];
        this.updates$
            .pipe(filter(function (data) { return data.command === command; }))
            .subscribe(function (data) {
            _this.logger.debug('Heartbeat received successfully');
        });
        var commandData = {
            Command: command,
            Data: {},
        };
        var input = thisWebSocketBridgeCommunication.serializer.convertCommandDataToWebsocketInputFormat(commandData);
        this.heartbeatTimer = setInterval(function () {
            thisWebSocketBridgeCommunication.webSocket.send(input);
            _this.logger.debug('Heartbeat sent');
        }, heartbeatIntervalSeconds * 1000);
    };
    WebSocketBridgeCommunication.prototype.getCompositionModel = function (apiName) {
        var _this = this;
        var thisWebSocketBridgeCommunication = this;
        var command = Commands[Commands.getModel];
        var promise = this.updates$
            .pipe(filter(function (data) { return data.command === command; }), first(), map(function (data) {
            return thisWebSocketBridgeCommunication.deserializer.getJsonDataFromGetModelRequest(data.stringData);
        }))
            .toPromise()
            .then(function (compositionModel) {
            if (!compositionModel) {
                var errorMessage = 'Model ' + apiName + ' not found';
                _this.logger.error(errorMessage);
                throw new Error(errorMessage);
            }
            _this.logger.info('Model ' + apiName + ' received successfully');
            return compositionModel;
        });
        var commandData = {
            Command: command,
            Data: { Name: apiName },
        };
        var input = thisWebSocketBridgeCommunication.serializer.convertCommandDataToWebsocketInputFormat(commandData);
        this.webSocket.send(input);
        return promise;
    };
    WebSocketBridgeCommunication.prototype.getXcApiList = function () {
        var _this = this;
        var thisWebSocketBridgeCommunication = this;
        var command = Commands[Commands.getXcApiList];
        var promise = this.updates$
            .pipe(filter(function (data) { return data.command === command; }), first(), map(function (data) {
            _this.logger.info('ApiList received successfully : ' + JSON.stringify(data));
            return thisWebSocketBridgeCommunication.deserializer.getJsonDataFromGetXcApiListRequest(data.stringData);
        }))
            .toPromise();
        var commandData = {
            Command: command,
            Data: {},
        };
        this.webSocket.send(thisWebSocketBridgeCommunication.serializer.convertCommandDataToWebsocketInputFormat(commandData));
        return promise;
    };
    WebSocketBridgeCommunication.prototype.getXcApiConfiguration = function (apiName) {
        var _this = this;
        var thisWebSocketBridgeCommunication = this;
        var command = Commands[Commands.getXcApi];
        var promise = this.updates$
            .pipe(filter(function (data) { return data.command === command; }), first(), map(function (data) {
            _this.logger.info(apiName + ' ' + 'received successfully');
            return thisWebSocketBridgeCommunication.deserializer.getJsonDataFromXcApiRequest(data.stringData);
        }))
            .toPromise()
            .then(function (xcApi) {
            if (!xcApi) {
                var errorMessage = "Unknown Api: ".concat(apiName);
                _this.logger.error(errorMessage);
                throw new Error(errorMessage);
            }
            var parser = new DefaultApiConfigurationParser();
            return parser.parse(xcApi);
        });
        var commandData = {
            Command: command,
            Data: { Name: apiName },
        };
        this.webSocket.send(thisWebSocketBridgeCommunication.serializer.convertCommandDataToWebsocketInputFormat(commandData));
        return promise;
    };
    WebSocketBridgeCommunication.prototype.dispose = function () {
        clearInterval(this.heartbeatTimer);
        this.runnning = false;
    };
    return WebSocketBridgeCommunication;
}());
export { WebSocketBridgeCommunication };
//# sourceMappingURL=WebSocketBridgeCommunication.js.map