import { WebSocketPublisher } from './WebSocketPublisher';
import { WebSocketSubscriber } from './WebSocketSubscriber';
import { PrivateTopics } from '../interfaces/PrivateTopics';
var WebSocketSession = /** @class */ (function () {
    function WebSocketSession(webSocketWrapper, configuration, sessionData) {
        this.subscriber = new WebSocketSubscriber(webSocketWrapper, configuration);
        this.privateTopics = new PrivateTopics(this.subscriber);
        this.publisher = new WebSocketPublisher(webSocketWrapper, configuration, this.privateTopics, sessionData);
        this.subscriber.setStateMachineRefSendPublisher(this.publisher);
    }
    WebSocketSession.prototype.send = function (componentName, stateMachineName, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic) {
        if (visibilityPrivate === void 0) { visibilityPrivate = false; }
        this.publisher.send(componentName, stateMachineName, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic);
    };
    WebSocketSession.prototype.canSend = function (componentName, stateMachineName, messageType) {
        return this.publisher.canSend(componentName, stateMachineName, messageType);
    };
    WebSocketSession.prototype.getSnapshot = function (componentName, stateMachineName) {
        return this.subscriber.getSnapshot(componentName, stateMachineName, this.privateTopics);
    };
    WebSocketSession.prototype.getStateMachineUpdates = function (componentName, stateMachineName) {
        return this.subscriber.getStateMachineUpdates(componentName, stateMachineName);
    };
    WebSocketSession.prototype.subscribe = function (componentName, stateMachineName, stateMachineUpdateListener) {
        this.subscriber.subscribe(componentName, stateMachineName, stateMachineUpdateListener);
    };
    WebSocketSession.prototype.unsubscribe = function (componentName, stateMachineName) {
        this.subscriber.unsubscribe(componentName, stateMachineName);
        throw new Error('Method not implemented.');
    };
    WebSocketSession.prototype.canSubscribe = function (componentName, stateMachineName) {
        return this.subscriber.canSubscribe(componentName, stateMachineName);
    };
    WebSocketSession.prototype.dispose = function () {
        this.privateTopics.dispose();
    };
    return WebSocketSession;
}());
export { WebSocketSession };
//# sourceMappingURL=WebSocketSession.js.map