import { Utils } from '../communication/Utils';
import { Kinds } from '../configuration/xcWebSocketBridgeConfiguration';
import { generateUUID } from '../utils/uuid';
var PrivateTopics = /** @class */ (function () {
    function PrivateTopics(subscriber) {
        this.subscriber = subscriber;
        this.defaultPublisherTopic = generateUUID();
        this.subscriberTopics = [];
        this.addSubscriberTopic(this.defaultPublisherTopic);
    }
    PrivateTopics.prototype.setDefaultPublisherTopic = function (newDefaultPublisherTopic) {
        if (newDefaultPublisherTopic) {
            this.addSubscriberTopic(newDefaultPublisherTopic);
            this.removeSubscriberTopic(this.defaultPublisherTopic);
            this.defaultPublisherTopic = newDefaultPublisherTopic;
        }
    };
    PrivateTopics.prototype.getDefaultPublisherTopic = function () {
        return this.defaultPublisherTopic;
    };
    PrivateTopics.prototype.addSubscriberTopic = function (privateTopic) {
        if (privateTopic && this.subscriberTopics.indexOf(privateTopic) === -1) {
            this.subscriber.sendSubscribeRequestToTopic(privateTopic, Kinds.Private);
            this.subscriberTopics.push(privateTopic);
        }
    };
    PrivateTopics.prototype.removeSubscriberTopic = function (privateTopic) {
        if (privateTopic && this.subscriberTopics.indexOf(privateTopic) !== -1) {
            this.subscriber.sendUnsubscribeRequestToTopic(privateTopic, Kinds.Private);
            Utils.removeElementFromArray(this.subscriberTopics, privateTopic);
        }
    };
    PrivateTopics.prototype.getSubscriberTopics = function () {
        return this.subscriberTopics;
    };
    PrivateTopics.prototype.dispose = function () {
        var _this = this;
        this.subscriberTopics.forEach(function (subscriberTopic) {
            _this.subscriber.sendUnsubscribeRequestToTopic(subscriberTopic, Kinds.Private);
        }, this);
    };
    return PrivateTopics;
}());
export { PrivateTopics };
//# sourceMappingURL=PrivateTopics.js.map